@@ -2,7 +2,9 @@ use std::net::Ipv4Addr;
 
 use crate::client::SteamClient;
 use crate::steam_id::SteamID;
-use crate::utils::{concat_steam_ids, Error, PlayersWrapper, ResponseWrapper, Result, AUTHORITY};
+use crate::utils::{
+    concat_steam_ids, Error, ErrorKind, PlayersWrapper, ResponseWrapper, Result, AUTHORITY,
+};
 use hyper::body::to_bytes;
 use hyper::Uri;
 use serde::Deserialize;
@@ -157,13 +159,13 @@ impl SteamClient {
     /// [Summaries](Summary) are in the same order as the [SteamIDs](SteamID).
     /// Always check the [SteamID] from the [Summary] struct.
     pub async fn get_player_summaries(&self, ids: Vec<SteamID>) -> Result<Vec<Summary>> {
-        let api_key = self.api_key.as_ref().ok_or(Error {
-            cause: "resolve_vanity_url requires an api key".to_owned(),
-        })?;
+        let api_key = self
+            .api_key()
+            .map_err(|_| Error::new(ErrorKind::APIKeyRequired))?;
         if ids.len() > 100 {
-            return Err(Error {
+            Err(Error::new(ErrorKind::Other {
                 cause: "Too many IDs for get_player_summaries()".to_owned(),
-            });
+            }))?;
         }
         let id_query = concat_steam_ids(ids);
         let query = format!("key={}&steamids={}", api_key, id_query);
