@@ -1,4 +1,4 @@
-use crate::utils::{Error, ResponseWrapper, Result, AUTHORITY};
+use crate::utils::{Error, ErrorKind, ResponseWrapper, Result, AUTHORITY};
 use crate::{SteamClient, SteamID};
 
 use hyper::body::to_bytes;
@@ -27,9 +27,9 @@ impl SteamClient {
     ///
     /// Requires an API key.
     pub async fn get_user_group_list(&self, id: SteamID) -> Result<Vec<SteamID>> {
-        let api_key = self.api_key.as_ref().ok_or(Error {
-            cause: "resolve_vanity_url requires an api key".to_owned(),
-        })?;
+        let api_key = self
+            .api_key()
+            .map_err(|_| Error::new(ErrorKind::APIKeyRequired))?;
         let query = format!("key={}&steamid={}", api_key, id);
         let uri = Uri::builder()
             .scheme("https")
@@ -50,9 +50,9 @@ impl SteamClient {
                 .map(|n| n.into())
                 .collect::<Vec<SteamID>>())
         } else {
-            Err(Error {
+            Err(Error::new(ErrorKind::Other {
                 cause: "Request failed".to_owned(),
-            })
+            }))
         }
     }
 }
